MambuPy
=======

[![Build Status](https://travis-ci.org/jstitch/MambuPy.svg?branch=master)](https://travis-ci.org/jstitch/MambuPy)


A python API for using Mambu.
-----------------------------

Allows accessing Mambu programatically.

Either using Mambu's REST API, or from within a Mambu's database
backup.

Mambu is a cloud platform which lets you rapidly build, integrate,
launch and service any lending portfolio into any market
(https://www.mambu.com).

Official documentation is found at https://mambupydocs.readthedocs.io


More Information
----------------

You can look at tha CHANGELOG for release notes.

MambuPy is licensed under GPLv3, LICENSE has more details.


Author
------

JNC
jstitch@gmail.com
